@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
 __author__ = "Paul Schifferer <dm@sweetrpg.com>"
-"""health.py
-Health endpoints.
+"""Health endpoints.
 """
